function [y,depth,dim,mmm,nbfoto] = fr_load (C_Taille)
%
% Fr_load admet la taille X*Y de l'image en paramètre. 
%  Elle recherche tout les fichier .pgm.oct du répertoire 
%  courant. Elle met en forme toutes les images au format 
%  vecteur colonne. Elle vérifie également la cohérence 
%  des données de ces images. 
%
%		nbfoto : nombre de photo du répertoire courant
%		y : Banque de données vecteur colonne image de taille 
%			[C_Taille,nbfoto]
%		depth : profondeur de couleur des images chargées
%		dim	: dimension [X,Y] d'une image
%		mmm : vecteur contenant des données calculée sur y 
%			[Teinte min, max , moyenne]
%		C_Taille : ceci est une contrainte (repr X*Y) 
%
%
%       Auteur  : Mathieu Deschamps
%                 mathdesc@scourge.fr
%       Date    : 11/02/2004 
%       IUT de Caen -- Licence Pro. M.C.A
%


   f=popen ("ls -1 *.pgm.oct | wc -l","r");
   n=fscanf(f,"%d");nbfoto=n;
   printf (" %d images .pgm.oct trouvées \n",n);fclose(f);
   f=popen("ls -1 *.pgm.oct","r");	

	for i=1:n
		file=fscanf(f,"%s",1);
		cmd=sprintf("load -force %s",file);file
		eval(cmd);

		 if (dims(1)*dims(2)!=C_Taille) 
			printf("%s: La taille de l'image [%i,%i] et le paramétre \nde la fonction %i doivent correspondre !\n",file,dims(1),dims(2),C_Taille);  
        		clear;
 		end

		X=reshape(X,C_Taille,1);
		depth=ncol;
		dim=dims;
			if !exist("y")
				y=X;
			else
				y=[y,X];
			end
	end
   mmm=[min(min(y)),max(max(y)),mean(mean(y))];
   if (  ((mmm(1)<0) || (mmm(1)>255))  ||  ((mmm(2)<0) || (mmm(2)>255)) || ((mmm(2)<0) || (mmm(2)>255))   )
 	printf("min: %i , max: %i , moyenne: %i valeur hors norme ! ",mmm(1),mmm(2),mmm(3));
	clear;
   end

   s=size(y);   

   if (s(1)!=C_Taille || s(2)!=n)
	printf ("Erreur lors du chargement ...");clear;
   end

   fclose (f);	   	

save load.save

